"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const execute_1 = require("./execute");
const imageHome_1 = require("./imageHome");
function newExecutionContext(inheritFrom) {
    return ExecutionContextImpl.create(inheritFrom);
}
exports.newExecutionContext = newExecutionContext;
class ExecutionContextImpl {
    constructor(imageHome = imageHome_1.createImageHome()) {
        this.imageHome = imageHome;
    }
    async execute(configOrCommands) {
        const config = asConfig(configOrCommands);
        config.inputFiles.forEach(f => {
            this.imageHome.register(f);
        });
        const inputFiles = await this.imageHome.getAll();
        const result = await execute_1.execute(Object.assign({}, config, { inputFiles }));
        result.outputFiles.forEach(f => {
            this.imageHome.register(f);
        });
        return result;
    }
    addFiles(files) {
        files.forEach(f => this.imageHome.register(f));
    }
    async getAllFiles() {
        return this.imageHome.getAll();
    }
    static create(inheritFrom) {
        if (inheritFrom && !inheritFrom.imageHome) {
            throw new Error('Dont know how to inherith from other ExecutionContext implementation than this one');
        }
        return new ExecutionContextImpl(inheritFrom && inheritFrom.imageHome);
    }
}
function asConfig(configOrCommands) {
    if (typeof configOrCommands === 'string') {
        return { inputFiles: [], commands: [configOrCommands] };
    }
    return configOrCommands.inputFiles ? configOrCommands :
        { commands: configOrCommands, inputFiles: [] };
}
//# sourceMappingURL=executionContext.js.map